@@ -10,6 +10,6 @@ from .utils import isotope_to_zaid
 from .utils import zaid_to_isotope
 from .utils import check_add_additional_end_lines
 from .utils import NATURAL_ABUNDANCE
+from .utils import SaveMaterialsToFile
 
 from .material import Material
-from .mutlimaterial import MultiMaterial
